@@ -34,7 +34,7 @@ Nil disables saving.")
   "Maximum length of a hyper-button label.")
 
 (defun    ebut:act (label)
-  "Activates Hyperbole explicit button with LABEL from the current buffer."
+  "Activate Hyperbole explicit button with LABEL from the current buffer."
   (interactive (list (hargs:read-match "Activate explicit button labeled: "
 				       (ebut:alist)
 				       nil t nil 'ebut)))
@@ -52,7 +52,7 @@ as a completion table."
 
 (defun    ebut:at-p (&optional start-delim end-delim)
   "Return explicit Hyperbole button at point or nil.
-Assumes point is within first line of button label, if at all.
+Assume point is within first line of button label, if at all.
 Optional START-DELIM and END-DELIM are strings that override default
 button delimiters."
   (let ((key (ebut:label-p nil start-delim end-delim)))
@@ -97,10 +97,10 @@ Return entry deleted (a list of attribute values) or nil."
   "Return explicit Hyperbole button symbol given by LBL-KEY and BUFFER.
 KEY-SRC is given when retrieving global buttons and is the full source pathname.
 
-Retrieves button data, converts into a button object and returns a symbol
+Retrieve button data, convert into a button object and return a symbol
 which references the button.
 
-All arguments are optional.  When none are given, returns a symbol for
+All arguments are optional.  When none are given, return a symbol for
 the button that point is within or nil.  BUFFER defaults to the current
 buffer."
   (hattr:clear 'hbut:current)
@@ -265,14 +265,14 @@ include delimiters when INCLUDE-DELIMS is non-nil)."
   (hbut:map but-func ebut:start ebut:end regexp-match include-delims))
 
 (defun    ebut:modify (&optional lbl-key but-sym)
-  "Modifies existing Hyperbole button from optional LBL-KEY and BUT-SYM.
+  "Modify existing Hyperbole button from optional LBL-KEY and BUT-SYM.
 Defaults are the key for any button label at point and `hbut:current'.
-If successful, returns button's instance number except when instance
-number is 1, then returns t.  On failure, as when button does not exist,
-returns nil.
+If successful, return button's instance number, except when instance
+number is 1, then return t.  On failure, as when button does not exist,
+return nil.
 
-If successful, leaves point in button data buffer, so caller should use
-`save-excursion'.  Does not save button data buffer."
+If successful, leave point in button data buffer, so caller should use
+`save-excursion'.  Do not save button data buffer."
   (save-excursion
     (let ((lbl-instance (hbdata:write lbl-key but-sym)))
       (run-hooks 'ebut-modify-hook)
@@ -302,7 +302,7 @@ If CURR-LABEL is nil, the text in the active region is used as the
 button label, if any, otherwise, an error is signaled.
 
 Return instance string appended to label to form a per-buffer unique
-label; nil if label is already unique.  Signals an error when no such
+label; nil if label is already unique.  Signal an error when no such
 button is found in the current buffer."
   (let* ((lbl-key (ebut:label-to-key curr-label))
 	 (lbl-regexp (ebut:label-regexp lbl-key))
@@ -311,13 +311,14 @@ button is found in the current buffer."
     (or new-label (setq new-label curr-label))
     (hattr:set 'hbut:current 'lbl-key (ebut:label-to-key new-label))
     (save-excursion
-      (if (setq instance-flag
-		(if modify (ebut:modify lbl-key) (ebut:create)))
-	  (if (hmail:editor-p) (hmail:msg-narrow))))
+      (when (setq instance-flag
+		  (if modify (ebut:modify lbl-key) (ebut:create)))
+	(when (hmail:editor-p)
+	  (hmail:msg-narrow))))
     (if instance-flag
 	(progn
-	  ;; Rename all occurrences of button - those with same label
 	  (if modify
+	      ;; Rename all occurrences of button - those with same label
 	      (let* ((but-key-and-pos (ebut:label-p nil nil nil 'pos))
 		     (at-but (equal (car but-key-and-pos)
 				    (ebut:label-to-key new-label))))
@@ -335,13 +336,23 @@ button is found in the current buffer."
 			lbl-regexp 'include-delims))
 		      (at-but)
 		      ((hypb:error "(ebut:operate): No button matching: %s" curr-label))))
+
 	    ;; Add a new button recording its start and end positions
-	    (let (start end buf-lbl)
-	      (cond ((and (not curr-label)
-			  (hmouse-use-region-p)
-			  (marker-position (hypb:mark-marker t))
-			  (setq start (region-beginning)
-				end (region-end)
+	    (let (start end mark prev-point buf-lbl)
+	      (cond ((not curr-label)
+		     (setq start (point))
+		     (insert new-label)
+		     (setq end (point)))
+		    ((and (hmouse-use-region-p)
+			  (setq mark (marker-position (hypb:mark-marker t)))
+			  (setq prev-point (and action-key-depress-prev-point
+						(marker-position action-key-depress-prev-point)))
+			  (setq start (if (and prev-point mark (<= prev-point mark))
+					  prev-point
+					(region-beginning))
+				end (if (and prev-point mark (> prev-point mark))
+					prev-point
+				      (region-end))
 				buf-lbl (buffer-substring start end))
 			  (equal buf-lbl curr-label))
 		     nil)
@@ -352,7 +363,14 @@ button is found in the current buffer."
 		    (t (setq start (point))
 		       (insert curr-label)
 		       (setq end (point))))
-	      (ebut:delimit start end instance-flag)))
+	      (ebut:delimit start end instance-flag)
+	      (goto-char start)))
+
+	  ;; Append any instance-flag string to the button label
+	  (when (stringp instance-flag)
+	    (setq new-label (concat new-label instance-flag))
+	    (hattr:set 'hbut:current 'lbl-key (ebut:label-to-key new-label)))
+
 	  ;; Position point
 	  (let ((new-key (ebut:label-to-key new-label)))
 	    (cond ((equal (ebut:label-p) new-key)
@@ -364,16 +382,18 @@ button is found in the current buffer."
 		     (or (re-search-forward  regexp nil t)
 			 (re-search-backward regexp nil t)))
 		   (goto-char (+ (match-beginning 0) (length ebut:start))))))
+
 	  ;; instance-flag might be 't which we don't want to return.
 	  (when (stringp instance-flag) instance-flag))
+
       (hypb:error
        "(ebut:operate): Operation failed.  Check button attribute permissions: %s"
        hattr:filename))))
 
 (defun    ebut:search (string out-buf &optional match-part)
-  "Writes explicit button lines matching STRING to OUT-BUF.
-Searches across all files into which the user has previously saved explicit buttons.
-By default, only matches for whole button labels are found; optional MATCH-PART
+  "Write explicit button lines matching STRING to OUT-BUF.
+Search across all files into which the user has previously saved explicit buttons.
+By default, find matches for whole button labels only; optional MATCH-PART
 enables partial matches."
   (let*  ((buffers (mapcar (lambda (dir)
 			     (expand-file-name hattr:filename dir))
@@ -476,26 +496,28 @@ Leave point inside the button label.  Return the symbol for the button, else nil
       (ebut:at-p))))
 
 ;;; ------------------------------------------------------------------------
-(defun    ebut:delimit (start end instance-str)
-  "Delimits button label spanning region START to END in current buffer.
-If button is already delimited or delimit fails, returns nil, else t.
-Inserts INSTANCE-STR after END, before ending delimiter."
+(defun    ebut:delimit (start end instance-flag)
+  "Delimit button label spanning region START to END in current buffer.
+If button is already delimited or delimit fails, return nil, else t.
+Insert INSTANCE-FLAG after END, before ending delimiter."
   (goto-char start)
-  (if (looking-at (regexp-quote ebut:start))
-      (forward-char (length ebut:start)))
+  (when (looking-at (regexp-quote ebut:start))
+    (forward-char (length ebut:start)))
   (unless (ebut:label-p)
     (setq start (move-marker (make-marker) start)
 	  end (move-marker (make-marker) end))
     (set-marker-insertion-type end t)
-    (if (not (stringp instance-str)) (setq instance-str ""))
+    ;; instance-flag may be 't to indicate don't add an instance number
+    (unless (stringp instance-flag)
+      (setq instance-flag ""))
     (insert ebut:start)
     (goto-char end)
-    (insert instance-str ebut:end)
+    (insert instance-flag ebut:end)
     ;; Insert any comment delimiter before the start marker.
     (set-marker-insertion-type start t)
     (hbut:comment start end)
-    (if (fboundp 'hproperty:but-add)
-	(hproperty:but-add start end hproperty:but))
+    (when (fboundp 'hproperty:but-add)
+      (hproperty:but-add start end hproperty:but))
     (goto-char end)
     (move-marker start nil)
     (move-marker end nil)
@@ -527,7 +549,7 @@ Inserts INSTANCE-STR after END, before ending delimiter."
   "File that stores globally accessible Hyperbole buttons, accessed by name.")
 
 (defun    gbut:act (label)
-  "Activates Hyperbole global button with LABEL."
+  "Activate Hyperbole global button with LABEL."
   (interactive (list (hargs:read-match "Activate global button labeled: "
 				       (mapcar 'list (gbut:label-list))
 				       nil t nil 'gbut)))
@@ -544,16 +566,16 @@ Inserts INSTANCE-STR after END, before ending delimiter."
 (defun    gbut:get (&optional lbl-key)
   "Return global Hyperbole button symbol given by optional LBL-KEY if found in gbut:file.
 
-Retrieves any button data, converts into a button object and returns a symbol
+Retrieve any button data, convert into a button object and return a symbol
 which references the button.
 
-All arguments are optional.  When none are given, returns a symbol for
+All arguments are optional.  When none are given, return a symbol for
 the button that point is within or nil."
   (or (ebut:get lbl-key nil gbut:file)
       (ibut:get lbl-key nil gbut:file)))
 
 (defun    gbut:help (label)
-  "Displays help for Hyperbole global button with LABEL."
+  "Display help for Hyperbole global button with LABEL."
   (interactive (list (hargs:read-match "Report on global button labeled: "
 				       (mapcar 'list (gbut:label-list))
 				       nil t nil 'hbut)))
@@ -635,8 +657,7 @@ Return the symbol for the button, else nil."
 	(progn
 	  (setcdr (cdr sublist) nil)
 	  (setplist hbut sublist))
-      (setplist hbut nil)
-      )))
+      (setplist hbut nil))))
 
 (defun    hattr:copy (from-hbut to-hbut)
   "Copy attributes FROM-HBUT TO-HBUT, overwriting TO-HBUT attribute values.
@@ -738,12 +759,19 @@ others who use a different value!")
 (defun    hbut:act (&optional hbut)
   "Perform action for optional explicit or implicit Hyperbole button symbol HBUT.
 Default is 'hbut:current."
+  (interactive (list (hbut:get (hargs:read-match "Activate labeled Hyperbole button: "
+						 (nconc (ebut:alist) (ibut:alist))
+						 nil t nil 'hbut))))
   (unless hbut
     (setq hbut 'hbut:current))
-  (when hbut
-    (apply hrule:action
-	   (hattr:get hbut 'actype)
-	   (hattr:get hbut 'args))))
+  (cond ((hbut:is-p hbut)
+	 (apply hrule:action
+		(hattr:get hbut 'actype)
+		(hattr:get hbut 'args)))
+	((and hbut (symbolp hbut))
+	 (hypb:error "(hbut:act): Symbol, %s, has invalid Hyperbole button attributes:\n  %S" hbut (hattr:list hbut)))
+	(t
+	 (hypb:error "(hbut:act): Invalid Hyperbole button: %s" hbut))))
 
 (defun    hbut:action (hbut)
   "Return appropriate action for Hyperbole button symbol HBUT."
@@ -765,8 +793,8 @@ Then use (hbut:act) to activate the button."
 
 (defun    hbut:comment (start end)
   "Comment button label spanning region START to END in current buffer.
-Usees buffer commenting grammar, if any, otherwise doesn't comment.
-Ignores email-related buffers."
+Use buffer commenting grammar, if any, otherwise don't comment.
+Ignore email-related buffers."
   (save-excursion
     (if (and comment-start (not (hmail:mode-is-p))
 	     (not (memq major-mode '(mail-mode message-mode))))
@@ -860,8 +888,8 @@ nil.  BUFFER defaults to the current buffer."
 
 (defun    hbut:key-src (&optional full)
   "Return key source (usually unqualified) for current Hyperbole button.
-Also sets current buffer to key source.
-With optional FULL when source is a pathname, the full pathname is returned."
+Als sets current buffer to key source.
+With optional FULL when source is a pathname, return the full pathname."
   (let ((src (cond ((hmail:mode-is-p) (current-buffer))
 		   ;; If buffer represents the output of a document
 		   ;; formatter, e.g. an Info document produced from a
@@ -938,7 +966,7 @@ represent the output of particular document formatters."
 	 src)))
 
 (defun    hbut:key-to-label (lbl-key)
-  "Unnormalizes LBL-KEY and returns a label string for display."
+  "Unnormalize LBL-KEY and return a label string for display."
   (if lbl-key
       (let* ((pos 0) (len (length lbl-key)) (lbl) c)
 	(while (< pos len)
@@ -963,13 +991,13 @@ represent the output of particular document formatters."
 
 (defun    hbut:label-p (&optional as-label start-delim end-delim pos-flag two-lines-flag)
   "Return key for the Hyperbole button label that point is within, else nil.
-Assumes point is within the first line of any button label.  All
-following arguments are optional.  If AS-LABEL is non-nil, label
-is returned rather than the key derived from the label.
+Assume point is within the first line of any button label.  All
+following arguments are optional.  If AS-LABEL is non-nil, return
+the label rather than the key derived from the label.
 START-DELIM and END-DELIM are strings that override default
-button delimiters.  With POS-FLAG non-nil, returns list of
+button delimiters.  With POS-FLAG non-nil, return list of
 label-or-key, but-start-position, but-end-position.  Positions
-include delimiters.  With TWO-LINES-FLAG non-nil, constrains
+include delimiters.  With TWO-LINES-FLAG non-nil, constrain
 label search to two lines."
   (or (ebut:label-p as-label start-delim end-delim pos-flag two-lines-flag)
       (ibut:label-p as-label start-delim end-delim pos-flag two-lines-flag)))
@@ -1003,10 +1031,10 @@ label; these default to `ebut:start' and `ebut:end'."
 	(setq regexp (concat regexp sep0 (regexp-quote (or end-delim ebut:end))))))))
 
 (defun    hbut:label-to-key (label)
-  "Normalizes LABEL for use as a Hyperbole button key and returns key.
-Eliminates any fill prefix in the middle of the label, replaces `_' with
-`__', removes leading and trailing whitespace and replaces each other
-whitespace sequence with `_'."
+  "Normalize LABEL for use as a Hyperbole button key and return key.
+Eliminate any fill prefix in the middle of the label, replace `_' with
+`__', remove leading and trailing whitespace and replace all other
+whitespace sequences with `_'."
   (when label
     (setq label (hbut:fill-prefix-remove label)
 	  ;; Remove leading and trailing space.
@@ -1017,12 +1045,12 @@ whitespace sequence with `_'."
 
 (defun    hbut:map (but-func &optional start-delim end-delim
 			     regexp-match include-delims)
-  "Applies BUT-FUNC to a set of Hyperbole buttons in the visible part of the current buffer.
+  "Apply BUT-FUNC to a set of Hyperbole buttons in the visible part of the current buffer.
 The set of buttons are those whose labels are delimited by optional START-DELIM and
 END-DELIM and that match any optional REGEXP-MATCH.
 
 START-DELIM defaults to ebut:start; END-DELIM defaults to ebut:end.
-If END-DELIM is a symbol, e.g. t, then START-DELIM is taken as a regular
+If END-DELIM is a symbol, e.g. t, then treat START-DELIM as a regular
 expression which matches an entire button string.
 
 BUT-FUNC must take precisely three arguments: the button label, the
@@ -1146,7 +1174,7 @@ Return number of buttons reported on or nil if none."
 
 (defun    hbut:source (&optional full)
   "Return Hyperbole source buffer or file given at point.
-If a file, always returns a full path if optional FULL is non-nil."
+If a file, always return a full path if optional FULL is non-nil."
   (goto-char (match-end 0))
   (cond ((looking-at "#<buffer \"?\\([^\n\"]+\\)\"?>")
 	 (get-buffer (match-string 1)))
@@ -1205,6 +1233,18 @@ source file for the buttons in the menu, if any.")
 ;;; ibut class - Implicit Hyperbole Buttons
 ;;; ========================================================================
 
+
+(defun    ibut:act (label)
+  "Activate Hyperbole implicit button with <[LABEL]> from the current buffer."
+  (interactive (list (hargs:read-match "Activate implicit button labeled: "
+				       (ibut:alist)
+				       nil t nil 'ibut)))
+  (let* ((lbl-key (hbut:label-to-key label))
+	 (but (ibut:get lbl-key)))
+    (if but
+	(hbut:act but)
+      (error "(ibut:act): No implicit button labeled: %s" label))))
+
 (defun    ibut:alist (&optional file)
   "Return alist of labeled ibuts in FILE or the current buffer.
 Each element is a list of just an implicit button label.  For use
@@ -1296,7 +1336,7 @@ KEY-SRC is given when retrieving global buttons and is the full source pathname.
 
 Return a symbol which references the button.
 
-All arguments are optional.  When none are given, returns a
+All arguments are optional.  When none are given, return a
 symbol for the button or button label that point is within or
 nil.  BUFFER defaults to the current buffer."
   (hattr:clear 'hbut:current)
@@ -1342,15 +1382,15 @@ Map over portion of buffer visible under any current restriction.
 BUT-FUNC must take precisely three arguments: the button label, the
 start position of the delimited button label and its end position (positions
 include delimiters when INCLUDE-DELIMS is non-nil).
-If END-DELIM is a symbol, e.g. t, then START-DELIM is taken as a regular
+If END-DELIM is a symbol, e.g. t, then treat START-DELIM as a regular
 expression which matches an entire button string."
   (hbut:map but-func ibut:label-start ibut:label-end))
 
 (defun    ibut:rename (old-lbl new-lbl)
-  "Modifies a label preceding a Hyperbole implicit button in the current buffer given by LBL-KEY.
-Signals an error when no such button is found in the current buffer.
+  "Modify a label preceding a Hyperbole implicit button in the current buffer given by LBL-KEY.
+Signal an error when no such button is found in the current buffer.
 
-Leaves point at the start of the button label which may be elsewhere
+Leave point at the start of the button label which may be elsewhere
 than the current point; callers should use `save-excursion` to retain
 current."
   ;; !! Need to handle adding instances to labels, similar to ebut:operate.
@@ -1368,7 +1408,7 @@ current."
 This is the normalized key form of an optional label that may
 precede an implicit button.  Use `ibut:at-p' instead to test if
 point is on either the implicit button text itself or the label.
-Assumes point is within the first line of any button label.
+Assume point is within the first line of any button label.
 
 All following arguments are optional.  If AS-LABEL is non-nil,
 label is returned rather than the key derived from the label.
