@@ -68,6 +68,8 @@
 ;;; Follows Org mode links and radio targets and cycles Org heading views
 ;;; ========================================================================
 
+;; Set the custom option `inhibit-hsys-org' non-nil to disable ALL Hyperbole
+;; support within Org major and minor modes.
 (require 'hsys-org)
 
 ;;; ========================================================================
@@ -151,7 +153,9 @@ display options."
     (let ((path (hpath:at-p))
 	      full-path)
       (if path
-	      (progn (apply #'ibut:label-set path (hpath:start-end path))
+	      (progn (when (string-match "\\`file://" path)
+				   (setq path (substring path (match-end 0))))
+				 (apply #'ibut:label-set path (hpath:start-end path))
 		         (hact 'link-to-file path))
 	    ;;
 	    ;; Match to Emacs Lisp and Info files without any directory component.
@@ -502,8 +506,8 @@ the very beginning of the line."
 	           (save-excursion
 	             (beginning-of-line)
 	             ;; Entry line within a TOC
-	             (if (looking-at "[ \t]+\\*+[ \t]+\\(.*[^ \t]\\)[ \t]*$")
-		             (setq section (match-string-no-properties 1))))
+	             (when (looking-at "[ \t]+\\*+[ \t]+\\(.*[^ \t]\\)[ \t]*$")
+		           (setq section (match-string-no-properties 1))))
 	           (progn (ibut:label-set section (match-beginning 1) (match-end 1))
 		              t)
 	           (save-excursion (re-search-backward
@@ -619,7 +623,7 @@ Requires the Emacs builtin Tramp library for ftp file retrievals."
       (ibut:label-set (hbut:key-to-label lbl-key) start-pos end-pos)
       (hact link-actype but-key key-file))))
 
-(defun  parse-label-and-file (label-and-file)
+(defun parse-label-and-file (label-and-file)
   "Parse a colon-separated string of button label and source file path into a list of label and file."
   ;; Can't use split-string here because file path may contain colons;
   ;; we want to split only on the first colon.
@@ -784,7 +788,11 @@ in grep and shell buffers."
       (beginning-of-line)
       (when (or
 	         ;; Grep matches, UNIX C compiler and Introl 68HC11 C compiler errors
-	         (looking-at "\\([^ \t\n\r:]+\\)[:\^@] ?\\([1-9][0-9]*\\)[ :]")
+	         (looking-at "\\([^ \t\n\r:]+\\): ?\\([1-9][0-9]*\\)[ :]")
+	         ;; Grep matches, UNIX C compiler and Introl 68HC11 C
+		 ;; compiler errors, allowing for file names with
+		 ;; spaces followed by a null character rather than a :
+	         (looking-at "\\([^\t\n\r]+\\)  ?\\([1-9][0-9]*\\)[ :]")
 	         ;; HP C compiler errors
 	         (looking-at "[a-zA-Z0-9]+: \"\\([^\t\n\r\",]+\\)\", line \\([0-9]+\\):")
 	         ;; BSO/Tasking 68HC08 C compiler errors
@@ -1237,7 +1245,7 @@ arg1 ... argN '>'.  For example, <mail nil \"user@somewhere.org\">."
 	    (setq var-flag t
 	          lbl (substring lbl 1)))
       (setq actype (if (string-match-p " "  lbl) (car (split-string lbl)) lbl)
-	        actype (or (intern-soft (concat "actype::" actype))
+	        actype (or (intern-soft (concat "actypes::" actype))
 		               (intern-soft actype)))
       ;; Ignore unbound symbols
       (unless (and actype (or (fboundp actype) (boundp actype)))
@@ -1254,12 +1262,12 @@ arg1 ... argN '>'.  For example, <mail nil \"user@somewhere.org\">."
 	          ((and (null args) (symbolp actype) (boundp actype)
 		            (or var-flag (not (fboundp actype))))
 	           ;; Is a variable, display its value as the action
-	           (setq args `(',actype)
+	           (setq args `(,actype)
 		             action `(display-variable ',actype)
 		             actype 'display-variable)))
 	    ;; Necessary so can return a null value, which actype:act cannot.
 	    (let ((hrule:action
-               (if (eq hrule:action #'actype:identity)
+			   (if (eq hrule:action #'actype:identity)
                    #'actype:identity
                  #'actype:eval)))
           (if (eq hrule:action #'actype:identity)
