@@ -29,16 +29,24 @@
 (require 'hbut)
 (require 'org)
 
+(defcustom inhibit-hsys-org nil
+  "*Non-nil means disable Action Key support in Org major and minor modes."
+  :type 'boolean
+  :initialize #'custom-initialize-default
+  :group 'hyperbole-buttons)
+
 (defvar hsys-org-mode-function #'hsys-org-mode-p
   "*Boolean function of no arguments that determines whether hsys-org actions are triggered or not.")
 
+;; Make Org-mode's M-RET binding activate implicit buttons
+(add-hook 'org-metareturn-hook #'hsys-org-hbut-activate-p)
+
 (defun hsys-org-mode-p ()
-  "Return non-nil if an Org-related major or minor mode is active in the current buffer."
+  "Return non-nil if point is within an Org major or minor-mode buffer."
   (or (derived-mode-p 'org-mode)
       (and (boundp 'outshine-mode) outshine-mode)
       (and (boundp 'poporg-mode) poporg-mode)))
 
-
 (defun hsys-org-cycle ()
   "Call `org-cycle' and force it to be set as `this-command' to cycle through all states."
   (setq last-command 'org-cycle
@@ -51,12 +59,18 @@
 	this-command 'org-cycle)
   (org-global-cycle nil))
 
+(defun hsys-org-hbut-activate-p ()
+  "When within an Org major or minor-mode buffer and `inhibit-hsys-org' is nil (the default), activate any Hyperbole button at point and return t, else return nil."
+  (when (and (not inhibit-hsys-org) (funcall hsys-org-mode-function) (hbut:at-p))
+    (hbut:act)
+    t))
+
 ;;; ************************************************************************
 ;;; Public Button Types
 ;;; ************************************************************************
 
 (defib org-mode ()
-  "Follows Org mode references, cycles outline visibility and executes code blocks.
+  "Follow Org mode references, cycles outline visibility and executes code blocks.
 
 First, this follows internal links in Org mode files.  When pressed on a
 link referent/target, the link definition is displayed, allowing two-way
@@ -72,26 +86,35 @@ cycles the view of the subtree at point.
 
 Fifth, with point on the first line of a code block definition, this
 executes the code block via the Org mode standard binding of {C-c C-c},
-(org-ctrl-c-ctrl-c).
+\(org-ctrl-c-ctrl-c).
 
 In any other context besides the end of a line, the Action Key invokes the
-Org mode standard binding of {M-RET}, (org-meta-return)."
-  (when (funcall hsys-org-mode-function)
-    (let (start-end)
-      (cond ((setq start-end (hsys-org-internal-link-target-at-p))
-	     (hsys-org-set-ibut-label start-end)
-	     (hact 'org-internal-link-target))
-	    ((hsys-org-radio-target-def-at-p)
-	     (hact 'org-radio-target))
-	    ((setq start-end (hsys-org-link-at-p))
-	     (hsys-org-set-ibut-label start-end)
-	     (hact 'org-link))
-	    ((org-at-heading-p)
-	     (hact 'hsys-org-cycle))
-	    ((hsys-org-at-block-start-p)
-	     (org-ctrl-c-ctrl-c))
-	    (t
-	     (hact 'org-meta-return))))))
+Org mode standard binding of {M-RET}, (org-meta-return).
+
+To disable ALL Hyperbole support within Org major and minor modes, set the
+custom option `inhibit-hsys-org' to t.  Then in Org modes, this will
+simply invoke `org-meta-return'."
+  (when (and (funcall hsys-org-mode-function)
+	     ;; Prevent infinite recursion when called via org-metareturn-hook
+	     ;; from org-meta-return invocation.
+	     (not (hyperb:stack-frame '(org-meta-return))))
+    (if inhibit-hsys-org
+	(hact 'org-meta-return)
+      (let (start-end)
+	(cond ((setq start-end (hsys-org-internal-link-target-at-p))
+	       (hsys-org-set-ibut-label start-end)
+	       (hact 'org-internal-link-target))
+	      ((hsys-org-radio-target-def-at-p)
+	       (hact 'org-radio-target))
+	      ((setq start-end (hsys-org-link-at-p))
+	       (hsys-org-set-ibut-label start-end)
+	       (hact 'org-link))
+	      ((org-at-heading-p)
+	       (hact 'hsys-org-cycle))
+	      ((hsys-org-at-block-start-p)
+	       (org-ctrl-c-ctrl-c))
+	      (t
+	       (hact 'org-meta-return)))))))
 
 (defun org-mode:help (&optional _but)
   "If on an Org mode heading, cycles through views of the whole buffer outline.
@@ -108,7 +131,10 @@ If on an Org mode link, displays standard Hyperbole help."
   "Follows an optional Org mode LINK to its target.
 If LINK is nil, follows any link at point.  Otherwise, triggers an error."
   (if (stringp link)
-      (org-open-link-from-string link) ;; autoloaded
+      (cond ((fboundp #'org-link-open-from-string)
+	     (org-link-open-from-string link))
+            ((fboundp #'org-open-link-from-string)
+	     (org-open-link-from-string link))) ;; autoloaded
     (org-open-at-point))) ;; autoloaded
 
 (defact org-internal-link-target (&optional link-target)
@@ -169,7 +195,9 @@ uses that one.  Otherwise, triggers an error."
 (defun hsys-org-link-at-p ()
   "Return non-nil iff point is on an Org mode link.
 Assumes caller has already checked that the current buffer is in `org-mode'."
-  (or (org-in-regexp org-any-link-re)
+  (or (if (boundp 'org-link-any-re)
+	  (org-in-regexp org-link-any-re)
+	(org-in-regexp org-any-link-re))
       (hsys-org-face-at-p 'org-link)))
 
 ;; Assumes caller has already checked that the current buffer is in org-mode.
