@@ -1216,21 +1216,21 @@ HYROLO-BUF may be a file-name, `buffer-name', or buffer."
 
 (defun hyrolo-format-name (name-str first last)
   "Reverse order of NAME-STR field given my regexp match field FIRST and LAST."
-  (if (match-beginning last)
-      (concat (substring name-str (match-beginning last) (match-end last))
-	      ", "
-	      (substring name-str (match-beginning first) (match-end first)))))
+  (when (match-beginning last)
+    (concat (substring name-str (match-beginning last) (match-end last))
+	    ", "
+	    (substring name-str (match-beginning first) (match-end first)))))
 
 (defun hyrolo-highlight-matches (regexp start end)
   "Highlight matches for REGEXP in region from START to END."
-  (if (fboundp 'hproperty:but-add)
-      (let ((hproperty:but-emphasize-flag))
-	(save-excursion
-	  (goto-char start)
-	  (while (re-search-forward regexp nil t)
-	    (hproperty:but-add (match-beginning 0) (match-end 0)
-			       (or hyrolo-highlight-face
-				   hproperty:highlight-face)))))))
+  (when (fboundp 'hproperty:but-add)
+    (let ((hproperty:but-emphasize-flag))
+      (save-excursion
+	(goto-char start)
+	(while (re-search-forward regexp nil t)
+	  (hproperty:but-add (match-beginning 0) (match-end 0)
+			     (or hyrolo-highlight-face
+				 hproperty:highlight-face)))))))
 
 (defun hyrolo-isearch-for-regexp (regexp)
   "Interactively search forward for the next occurrence of current match REGEXP.
